@@ -41,13 +41,13 @@ key_patterns = {2: {
                     'results': 'tethys/v4/{dataset_id}/{version_date}/{station_id}/{chunk_id}.results.nc.zst',
                     'datasets': 'tethys/v4.datasets.json.zst',
                     'stations': 'tethys/v4/{dataset_id}/{version_date}.stations.json.zst',
-                    'latest_stations': 'tethys/v4/{dataset_id}.stations.json.zst',
+                    # 'latest_stations': 'tethys/v4/{dataset_id}.stations.json.zst',
                     # 'station': 'tethys/v4/{dataset_id}/{version_date}/{station_id}.station.json.zst',
                     # 'latest_station': 'tethys/v4/{dataset_id}/{station_id}.station.json.zst',
                     'dataset': 'tethys/v4/{dataset_id}.dataset.json.zst',
                     'versions': 'tethys/v4/{dataset_id}.versions.json.zst',
                     'results_chunks': 'tethys/v4/{dataset_id}/{version_date}.results_chunks.json.zst',
-                    'latest_results_chunks': 'tethys/v4/{dataset_id}.results_chunks.json.zst',
+                    # 'latest_results_chunks': 'tethys/v4/{dataset_id}.results_chunks.json.zst',
                     'diagnostics': 'tethys/v4/diagnostics/{run_id}.json.zst',
                     'interim_results': 'tethys/v4/interim/{run_id}/{dataset_id}/{station_id}.{start_date}.nc.zst'
                     }
